@@ -244,7 +244,7 @@ class StepGraph(object):
 
         sources = list()
         for x in assets.source:
-            if x._defined:
+            if x is not None:
                 for y in x:
                     sources.append(y)
 
@@ -607,7 +607,9 @@ class StoredEntity(object):
         self.clsname = clsname
         self.entityname = entityname
     def resurrect(self, model):
-        if '.' in self.clsname:
+        if self.clsname == 'NoneType':
+            return None
+        elif '.' in self.clsname:
             module_name, cls_name = self.clsname.rsplit('.', 1)
             module = import_module(module_name)
         else:
@@ -1399,8 +1401,10 @@ class PersistentTaskList(object):
             sql_se = sql_template % {'se': '=?', 'ss': ' IS NULL'}
             sql_ss = sql_template % {'ss': '=?', 'se': ' IS NULL'}
             candidates = None # candidate known tasks
-            for (label, asset) in zip(sources._fields, sources):
+            for (label, asset, assetattr) in zip(sources._fields, sources, sources._sources):
                 # loop over the source assets
+                if asset is None and assetattr.allownone:
+                    continue
                 asset_items = tuple(cn for cn in asset.iteritems())
                 if isinstance(asset, core.FileSequence):
                     # if a sequence we also need to ensure that the sequence itself is tracked
@@ -1602,9 +1606,12 @@ class PersistentTaskList(object):
                 sql = sql_ss
             else:
                 sequence_id = None
-                if not asset._defined:
-                    # if the asset is not defined here, it can / should only be because it is allowed to be None
-                    se_id = self.id_stored_entity(type(asset), None).id
+                if asset is None:
+                    # if the asset is not defined here, 
+                    # it can / should only be the case
+                    # because it is allowed to be None
+                    continue
+                    #se_id = self.id_stored_entity(type(asset), None).id
                 else:
                     for se_i, cn in enumerate(asset.iteritems()):
                         if se_i > 0:
